@@ -1,6 +1,6 @@
 /*
  *  libMirage: CSO filter
- *  Copyright (C) 2012-2014 Henrik Stokseth
+ *  Copyright (C) 2012-2026 Henrik Stokseth
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifndef __FILTER_CSO_H__
-#define __FILTER_CSO_H__
+#pragma once
 
 #include "mirage/config.h"
 #include <mirage/mirage.h>
@@ -30,19 +29,21 @@
 
 G_BEGIN_DECLS
 
+
 #pragma pack(1)
+
 typedef struct
 {
-    gchar   magic[4];       /* "CISO" signature                   */
-    guint32 header_size;    /* One tool fail to set this value    */
-    guint64 total_bytes;    /* Uncompressed data size             */
-    guint32 block_size;     /* Uncompressed sector size           */
-    guint8  version;        /* Version                            */
-    guint8  idx_align;      /* Alignment of index value = 2^align */
-    guint16 reserved;       /* Reserved                           */
-} ciso_header_t;            /* Length: 24 bytes                   */
+    gchar magic[4]; /* "CISO" signature */
+    guint32 header_size; /* One tool fail to set this value */
+    guint64 total_bytes; /* Uncompressed data size */
+    guint32 block_size; /* Uncompressed sector size */
+    guint8 version; /* Version */
+    guint8 idx_align; /* Alignment of index value = 2^align */
+    guint16 reserved; /* Reserved */
+} ciso_header_t; /* Length: 24 bytes */
+
 #pragma pack()
 
-G_END_DECLS
 
-#endif /* __FILTER_CSO_H__ */
+G_END_DECLS
