@@ -1,6 +1,6 @@
 /*
  *  libMirage: DMG filter: Apple Data Compression (ADC) decompression
- *  Copyright (C) 2012-2014 Henrik Stokseth
+ *  Copyright (C) 2012-2026 Henrik Stokseth
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,11 +17,8 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifndef __FILTER_DMG_ADC_H__
-#define __FILTER_DMG_ADC_H__
+#pragma once
 
 #include <glib.h>
 
 gsize adc_decompress(gsize in_size, guint8 *input, gsize avail_size, guint8 *output, gsize *bytes_written);
-
-#endif /* __FILTER_DMG_ADC_H__ */
