@@ -1,6 +1,6 @@
 /*
  *  libMirage: DMG filter: filter stream
- *  Copyright (C) 2012-2014 Henrik Stokseth
+ *  Copyright (C) 2012-2026 Henrik Stokseth
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,22 +22,23 @@
 #define __debug__ "DMG-FilterStream"
 
 
-static const guint8 koly_signature[4] = { 'k', 'o', 'l', 'y' };
-/*static const guint8 mish_signature[4] = { 'm', 'i', 's', 'h' };*/
+static const guint8 koly_signature[4] = {'k', 'o', 'l', 'y'};
+/*static const guint8 mish_signature[4] = {'m', 'i', 's', 'h'};*/
 
-typedef struct {
+typedef struct
+{
     DMG_block_type type;
 
-    guint64  first_sector;
-    guint64  num_sectors;
-    gint     segment;
-    goffset  in_offset;
-    gsize    in_length;
+    guint64 first_sector;
+    guint64 num_sectors;
+    gint segment;
+    goffset in_offset;
+    gsize in_length;
 } DMG_Part;
 
 
 /**********************************************************************\
- *                          Private structure                         *
+ *                  Object and its private structure                  *
 \**********************************************************************/
 struct _MirageFilterStreamDmgPrivate
 {
@@ -54,7 +55,7 @@ struct _MirageFilterStreamDmgPrivate
 
     /* Part list */
     DMG_Part *parts;
-    gint num_parts;
+    guint num_parts;
 
     /* Inflate buffer */
     guint8 *inflate_buffer;
@@ -71,6 +72,20 @@ struct _MirageFilterStreamDmgPrivate
 };
 
 
+G_DEFINE_DYNAMIC_TYPE_EXTENDED(
+    MirageFilterStreamDmg,
+    mirage_filter_stream_dmg,
+    MIRAGE_TYPE_FILTER_STREAM,
+    0,
+    G_ADD_PRIVATE_DYNAMIC(MirageFilterStreamDmg)
+)
+
+void mirage_filter_stream_dmg_type_register (GTypeModule *type_module)
+{
+    mirage_filter_stream_dmg_register_type(type_module);
+}
+
+
 /**********************************************************************\
  *                    Endian-conversion functions                     *
 \**********************************************************************/
@@ -78,19 +93,19 @@ static inline void mirage_filter_stream_dmg_koly_block_fix_endian (koly_block_t
 {
     g_assert(koly_block);
 
-    koly_block->version       = GUINT32_FROM_BE(koly_block->version);
-    koly_block->header_size   = GUINT32_FROM_BE(koly_block->header_size);
-    koly_block->flags         = GUINT32_FROM_BE(koly_block->flags);
+    koly_block->version = GUINT32_FROM_BE(koly_block->version);
+    koly_block->header_size = GUINT32_FROM_BE(koly_block->header_size);
+    koly_block->flags = GUINT32_FROM_BE(koly_block->flags);
     koly_block->image_variant = GUINT32_FROM_BE(koly_block->image_variant);
 
     koly_block->running_data_fork_offset = GUINT64_FROM_BE(koly_block->running_data_fork_offset);
-    koly_block->data_fork_offset         = GUINT64_FROM_BE(koly_block->data_fork_offset);
-    koly_block->data_fork_length         = GUINT64_FROM_BE(koly_block->data_fork_length);
-    koly_block->rsrc_fork_offset         = GUINT64_FROM_BE(koly_block->rsrc_fork_offset);
-    koly_block->rsrc_fork_length         = GUINT64_FROM_BE(koly_block->rsrc_fork_length);
-    koly_block->xml_offset               = GUINT64_FROM_BE(koly_block->xml_offset);
-    koly_block->xml_length               = GUINT64_FROM_BE(koly_block->xml_length);
-    koly_block->sector_count             = GUINT64_FROM_BE(koly_block->sector_count);
+    koly_block->data_fork_offset = GUINT64_FROM_BE(koly_block->data_fork_offset);
+    koly_block->data_fork_length = GUINT64_FROM_BE(koly_block->data_fork_length);
+    koly_block->rsrc_fork_offset = GUINT64_FROM_BE(koly_block->rsrc_fork_offset);
+    koly_block->rsrc_fork_length = GUINT64_FROM_BE(koly_block->rsrc_fork_length);
+    koly_block->xml_offset = GUINT64_FROM_BE(koly_block->xml_offset);
+    koly_block->xml_length = GUINT64_FROM_BE(koly_block->xml_length);
+    koly_block->sector_count = GUINT64_FROM_BE(koly_block->sector_count);
 
     koly_block->segment_number = GUINT32_FROM_BE(koly_block->segment_number);
     koly_block->segment_count  = GUINT32_FROM_BE(koly_block->segment_count);
@@ -99,8 +114,8 @@ static inline void mirage_filter_stream_dmg_koly_block_fix_endian (koly_block_t
 
     koly_block->data_fork_checksum.type = GUINT32_FROM_BE(koly_block->data_fork_checksum.type);
     koly_block->data_fork_checksum.size = GUINT32_FROM_BE(koly_block->data_fork_checksum.size);
-    koly_block->master_checksum.type    = GUINT32_FROM_BE(koly_block->master_checksum.type);
-    koly_block->master_checksum.size    = GUINT32_FROM_BE(koly_block->master_checksum.size);
+    koly_block->master_checksum.type = GUINT32_FROM_BE(koly_block->master_checksum.type);
+    koly_block->master_checksum.size = GUINT32_FROM_BE(koly_block->master_checksum.size);
 
     for (guint i = 0; i < 32; i++) {
         koly_block->master_checksum.data[i] = GUINT32_FROM_BE(koly_block->master_checksum.data[i]);
@@ -121,15 +136,15 @@ static inline void mirage_filter_stream_dmg_blkx_block_fix_endian (blkx_block_t
     blkx_block->info_version = GUINT32_FROM_BE(blkx_block->info_version);
 
     blkx_block->first_sector_number = GUINT64_FROM_BE(blkx_block->first_sector_number);
-    blkx_block->sector_count        = GUINT64_FROM_BE(blkx_block->sector_count);
-    blkx_block->data_start          = GUINT64_FROM_BE(blkx_block->data_start);
+    blkx_block->sector_count = GUINT64_FROM_BE(blkx_block->sector_count);
+    blkx_block->data_start = GUINT64_FROM_BE(blkx_block->data_start);
 
     blkx_block->decompressed_buffer_requested = GUINT32_FROM_BE(blkx_block->decompressed_buffer_requested);
 
     blkx_block->blocks_descriptor = GINT32_FROM_BE(blkx_block->blocks_descriptor);
-    blkx_block->blocks_run_count  = GUINT32_FROM_BE(blkx_block->blocks_run_count);
-    blkx_block->checksum.type     = GUINT32_FROM_BE(blkx_block->checksum.type);
-    blkx_block->checksum.size     = GUINT32_FROM_BE(blkx_block->checksum.size);
+    blkx_block->blocks_run_count = GUINT32_FROM_BE(blkx_block->blocks_run_count);
+    blkx_block->checksum.type = GUINT32_FROM_BE(blkx_block->checksum.type);
+    blkx_block->checksum.size = GUINT32_FROM_BE(blkx_block->checksum.size);
 
     for (guint i = 0; i < 32; i++) {
         blkx_block->checksum.data[i] = GUINT32_FROM_BE(blkx_block->checksum.data[i]);
@@ -144,8 +159,8 @@ static inline void mirage_filter_stream_dmg_blkx_data_fix_endian (blkx_data_t *b
 
     blkx_data->block_type = GINT32_FROM_BE(blkx_data->block_type);
 
-    blkx_data->sector_offset     = GUINT64_FROM_BE(blkx_data->sector_offset);
-    blkx_data->sector_count      = GUINT64_FROM_BE(blkx_data->sector_count);
+    blkx_data->sector_offset = GUINT64_FROM_BE(blkx_data->sector_offset);
+    blkx_data->sector_count = GUINT64_FROM_BE(blkx_data->sector_count);
     blkx_data->compressed_offset = GUINT64_FROM_BE(blkx_data->compressed_offset);
     blkx_data->compressed_length = GUINT64_FROM_BE(blkx_data->compressed_length);
 }
@@ -155,23 +170,23 @@ static inline void mirage_filter_stream_dmg_csum_fix_endian (csum_block_t *csum_
     g_assert(csum_block);
 
     csum_block->version = GUINT16_FROM_LE(csum_block->version);
-    csum_block->type    = GUINT16_FROM_LE(csum_block->type);
-    csum_block->data    = GUINT32_FROM_LE(csum_block->data);
+    csum_block->type = GUINT16_FROM_LE(csum_block->type);
+    csum_block->data = GUINT32_FROM_LE(csum_block->data);
 }
 
 static inline void mirage_filter_stream_dmg_size_fix_endian (size_block_t *size_block)
 {
     g_assert(size_block);
 
-    size_block->version        = GUINT16_FROM_LE(size_block->version);
-    size_block->is_hfs         = GUINT32_FROM_LE(size_block->is_hfs);
-    size_block->unknown1       = GUINT32_FROM_LE(size_block->unknown1);
-    size_block->unknown2       = GUINT32_FROM_LE(size_block->unknown2);
-    size_block->unknown3       = GUINT32_FROM_LE(size_block->unknown3);
-    size_block->vol_modified   = GUINT32_FROM_LE(size_block->vol_modified);
-    size_block->unknown4       = GUINT32_FROM_LE(size_block->unknown4);
+    size_block->version = GUINT16_FROM_LE(size_block->version);
+    size_block->is_hfs = GUINT32_FROM_LE(size_block->is_hfs);
+    size_block->unknown1 = GUINT32_FROM_LE(size_block->unknown1);
+    size_block->unknown2 = GUINT32_FROM_LE(size_block->unknown2);
+    size_block->unknown3 = GUINT32_FROM_LE(size_block->unknown3);
+    size_block->vol_modified = GUINT32_FROM_LE(size_block->vol_modified);
+    size_block->unknown4 = GUINT32_FROM_LE(size_block->unknown4);
     size_block->vol_sig.as_int = GUINT16_FROM_BE(size_block->vol_sig.as_int);
-    size_block->size_present   = GUINT16_FROM_LE(size_block->size_present);
+    size_block->size_present = GUINT16_FROM_LE(size_block->size_present);
 }
 
 
@@ -298,12 +313,16 @@ static void mirage_filter_stream_dmg_print_size_block(MirageFilterStreamDmg *sel
 \**********************************************************************/
 static gchar *create_filename_func (const gchar *main_filename, gint index)
 {
-    if (!main_filename) return NULL;
+    if (!main_filename) {
+        return NULL;
+    }
 
     gint  main_fn_len = strlen(main_filename) - 7;
     gchar *ret_filename = g_try_malloc(main_fn_len + 12);
 
-    if (!ret_filename) return NULL;
+    if (!ret_filename) {
+        return NULL;
+    }
 
     /* Copy base filename without 'NNN.dmg' */
     memcpy(ret_filename, main_filename, main_fn_len);
@@ -323,7 +342,7 @@ static gboolean mirage_filter_stream_dmg_read_descriptor (MirageFilterStreamDmg
 {
     koly_block_t *koly_block = self->priv->koly_block;
     rsrc_fork_t  *rsrc_fork = NULL;
-    gchar        *rsrc_fork_data = NULL;
+    gchar *rsrc_fork_data = NULL;
 
     /* Read and parse resource-fork */
     if (koly_block->xml_offset && koly_block->xml_length) {
@@ -334,7 +353,7 @@ static gboolean mirage_filter_stream_dmg_read_descriptor (MirageFilterStreamDmg
         }
 
         mirage_stream_seek(stream, koly_block->xml_offset, G_SEEK_SET, NULL);
-        if (mirage_stream_read(stream, rsrc_fork_data, koly_block->xml_length, NULL) != koly_block->xml_length) {
+        if ((gsize)mirage_stream_read(stream, rsrc_fork_data, koly_block->xml_length, NULL) != koly_block->xml_length) {
             g_set_error(error, MIRAGE_ERROR, MIRAGE_ERROR_IMAGE_FILE_ERROR, Q_("Failed to read XML resource-fork!"));
             return FALSE;
         }
@@ -348,7 +367,7 @@ static gboolean mirage_filter_stream_dmg_read_descriptor (MirageFilterStreamDmg
         }
 
         mirage_stream_seek(stream, koly_block->rsrc_fork_offset, G_SEEK_SET, NULL);
-        if (mirage_stream_read(stream, rsrc_fork_data, koly_block->rsrc_fork_length, NULL) != koly_block->rsrc_fork_length) {
+        if ((gsize)mirage_stream_read(stream, rsrc_fork_data, koly_block->rsrc_fork_length, NULL) != koly_block->rsrc_fork_length) {
             g_set_error(error, MIRAGE_ERROR, MIRAGE_ERROR_IMAGE_FILE_ERROR, Q_("Failed to read binary resource-fork!"));
             return FALSE;
         }
@@ -376,10 +395,8 @@ static gboolean mirage_filter_stream_dmg_read_descriptor (MirageFilterStreamDmg
         for (guint r = 0; r < rsrc_type->ref_list->len; r++) {
             rsrc_ref_t *rsrc_ref = &g_array_index(rsrc_type->ref_list, rsrc_ref_t, r);
 
-            MIRAGE_DEBUG(self, MIRAGE_DEBUG_PARSER, "%s: Resource Type: %.4s ID: %i Name: %s\n", __debug__,
-                         rsrc_type->type.as_array, rsrc_ref->id, rsrc_ref->name->str);
-            MIRAGE_DEBUG(self, MIRAGE_DEBUG_PARSER, "%s:  Attrs: 0x%04hx Data length: %i\n", __debug__,
-                         rsrc_ref->attrs, rsrc_ref->data_length);
+            MIRAGE_DEBUG(self, MIRAGE_DEBUG_PARSER, "%s: Resource Type: %.4s ID: %i Name: %s\n", __debug__, rsrc_type->type.as_array, rsrc_ref->id, rsrc_ref->name->str);
+            MIRAGE_DEBUG(self, MIRAGE_DEBUG_PARSER, "%s:  Attrs: 0x%04hx Data length: %i\n", __debug__, rsrc_ref->attrs, rsrc_ref->data_length);
 
             /* Convert resource endianness */
             if (!memcmp(rsrc_type->type.as_array, "plst", 4)) {
@@ -403,12 +420,12 @@ static gboolean mirage_filter_stream_dmg_read_descriptor (MirageFilterStreamDmg
                 nsiz_data = g_string_new_len(rsrc_ref->data, rsrc_ref->data_length);
                 g_assert(nsiz_data);
 
-                g_printf("\n%s\n", nsiz_data->str);
+                MIRAGE_DEBUG(self, MIRAGE_DEBUG_PARSER, "%s: nsiz data: %s\n", __debug__, nsiz_data->str);
 
                 g_string_free(nsiz_data, TRUE);
             } else if (!memcmp(rsrc_type->type.as_array, "blkx", 4)) {
-                blkx_block_t *blkx_block = (blkx_block_t *) rsrc_ref->data;
-                blkx_data_t  *blkx_data  = (blkx_data_t *) (rsrc_ref->data + sizeof(blkx_block_t));
+                blkx_block_t *blkx_block = (blkx_block_t *)rsrc_ref->data;
+                blkx_data_t  *blkx_data  = (blkx_data_t *)(rsrc_ref->data + sizeof(blkx_block_t));
 
                 mirage_filter_stream_dmg_blkx_block_fix_endian(blkx_block);
                 for (guint d = 0; d < blkx_block->blocks_run_count; d++) {
@@ -444,12 +461,12 @@ static gboolean mirage_filter_stream_dmg_read_descriptor (MirageFilterStreamDmg
 
 static gboolean mirage_filter_stream_dmg_read_index (MirageFilterStreamDmg *self, GError **error)
 {
-    z_stream  *zlib_stream  = &self->priv->zlib_stream;
+    z_stream *zlib_stream  = &self->priv->zlib_stream;
     bz_stream *bzip2_stream = &self->priv->bzip2_stream;
 
     koly_block_t *koly_block = self->priv->koly_block;
-    rsrc_fork_t  *rsrc_fork = self->priv->rsrc_fork;
-    rsrc_type_t  *rsrc_type = NULL;
+    rsrc_fork_t *rsrc_fork = self->priv->rsrc_fork;
+    rsrc_type_t *rsrc_type = NULL;
 
     gint cur_part = 0;
     gint ret;
@@ -491,8 +508,8 @@ static gboolean mirage_filter_stream_dmg_read_index (MirageFilterStreamDmg *self
 
             /* Find segment belonging to part */
             temp_part.segment = -1;
-            for (gint s = 0; s < self->priv->num_koly_blocks; s++) {
-                if (temp_part.in_offset >= koly_block[s].running_data_fork_offset) {
+            for (guint s = 0; s < self->priv->num_koly_blocks; s++) {
+                if (temp_part.in_offset >= (goffset)koly_block[s].running_data_fork_offset) {
                     temp_part.segment = s;
                 } else {
                     break;
@@ -748,14 +765,14 @@ end:
 static gssize mirage_filter_stream_dmg_read_raw_chunk (MirageFilterStreamDmg *self, guint8 *buffer, gint chunk_num)
 {
     const DMG_Part *part = &self->priv->parts[chunk_num];
-    MirageStream   *stream = self->priv->streams[part->segment];
-    koly_block_t   *koly_block = &self->priv->koly_block[part->segment];
+    MirageStream *stream = self->priv->streams[part->segment];
+    koly_block_t *koly_block = &self->priv->koly_block[part->segment];
 
-    gsize   to_read = part->in_length;
-    gsize   have_read = 0;
+    gsize to_read = part->in_length;
+    gsize have_read = 0;
     goffset part_offs = koly_block->data_fork_offset + part->in_offset - koly_block->running_data_fork_offset;
-    gsize   part_avail = koly_block->running_data_fork_offset + koly_block->data_fork_length - part->in_offset;
-    gint    ret;
+    gsize part_avail = koly_block->running_data_fork_offset + koly_block->data_fork_length - part->in_offset;
+    gssize ret;
 
     /* Seek to the position */
     if (!mirage_stream_seek(stream, part_offs, G_SEEK_SET, NULL)) {
@@ -773,10 +790,10 @@ static gssize mirage_filter_stream_dmg_read_raw_chunk (MirageFilterStreamDmg *se
     } else if (ret == 0) {
         MIRAGE_DEBUG(self, MIRAGE_DEBUG_WARNING, "%s: unexpectedly reached EOF!\n", __debug__);
         return -1;
-    } else if (ret == to_read) {
+    } else if ((gsize)ret == to_read) {
         have_read += ret;
         to_read -= ret;
-    } else if (ret < to_read) {
+    } else if ((gsize)ret < to_read) {
         MIRAGE_DEBUG(self, MIRAGE_DEBUG_PARSER, "%s: reading remaining data!\n", __debug__);
         have_read += ret;
         to_read -= ret;
@@ -799,7 +816,7 @@ static gssize mirage_filter_stream_dmg_read_raw_chunk (MirageFilterStreamDmg *se
         } else if (ret == 0) {
             MIRAGE_DEBUG(self, MIRAGE_DEBUG_WARNING, "%s: unexpectedly reached EOF!\n", __debug__);
             return -1;
-        } else if (ret == to_read) {
+        } else if ((gsize)ret == to_read) {
             have_read += ret;
             to_read -= ret;
         }
@@ -817,9 +834,9 @@ static gssize mirage_filter_stream_dmg_partial_read (MirageFilterStream *_self,
     gint part_idx = -1;
 
     /* Find part that corresponds to current position */
-    for (gint p = 0; p < self->priv->num_parts; p++) {
+    for (guint p = 0; p < self->priv->num_parts; p++) {
         DMG_Part *cur_part = &self->priv->parts[p];
-        gint req_sector = position / DMG_SECTOR_SIZE;
+        guint req_sector = position / DMG_SECTOR_SIZE;
 
         if ((cur_part->first_sector <= req_sector) && (cur_part->first_sector + cur_part->num_sectors >= req_sector)) {
             part_idx = p;
@@ -836,9 +853,6 @@ static gssize mirage_filter_stream_dmg_partial_read (MirageFilterStream *_self,
     /* If we do not have part in cache, uncompress it */
     if (part_idx != self->priv->cached_part) {
         const DMG_Part *part = &self->priv->parts[part_idx];
-        z_stream *zlib_stream = &self->priv->zlib_stream;
-        bz_stream *bzip2_stream = &self->priv->bzip2_stream;
-        gint ret;
 
         MIRAGE_DEBUG(self, MIRAGE_DEBUG_STREAM, "%s: part not cached, reading...\n", __debug__);
 
@@ -847,89 +861,98 @@ static gssize mirage_filter_stream_dmg_partial_read (MirageFilterStream *_self,
             /* We don't use internal buffers for zero data */
         } else if (part->type == RAW) {
             /* Read uncompressed part */
-            ret = mirage_filter_stream_dmg_read_raw_chunk (self, self->priv->inflate_buffer, part_idx);
-            if (ret != part->in_length) {
+            gssize ret = mirage_filter_stream_dmg_read_raw_chunk (self, self->priv->inflate_buffer, part_idx);
+            if ((gsize)ret != part->in_length) {
                 MIRAGE_DEBUG(self, MIRAGE_DEBUG_WARNING, "%s: failed to read raw chunk!\n", __debug__);
                 return -1;
             }
         } else if (part->type == ZLIB) {
+            z_stream *zlib_stream = &self->priv->zlib_stream;
+            int zlib_ret;
+            gssize read_bytes;
+
             /* Reset inflate engine */
-            ret = inflateReset2(zlib_stream, 15);
-            if (ret != Z_OK) {
+            zlib_ret = inflateReset2(zlib_stream, 15);
+            if (zlib_ret != Z_OK) {
                 MIRAGE_DEBUG(self, MIRAGE_DEBUG_WARNING, "%s: failed to reset inflate engine!\n", __debug__);
                 return -1;
             }
 
             /* Uncompress whole part */
-            zlib_stream->avail_in  = part->in_length;
-            zlib_stream->next_in   = self->priv->io_buffer;
+            zlib_stream->avail_in = part->in_length;
+            zlib_stream->next_in = self->priv->io_buffer;
             zlib_stream->avail_out = self->priv->inflate_buffer_size;
-            zlib_stream->next_out  = self->priv->inflate_buffer;
+            zlib_stream->next_out = self->priv->inflate_buffer;
 
             /* Read some compressed data */
-            ret = mirage_filter_stream_dmg_read_raw_chunk (self, self->priv->io_buffer, part_idx);
-            if (ret != part->in_length) {
+            read_bytes = mirage_filter_stream_dmg_read_raw_chunk (self, self->priv->io_buffer, part_idx);
+            if ((gsize)read_bytes != part->in_length) {
                 MIRAGE_DEBUG(self, MIRAGE_DEBUG_WARNING, "%s: failed to read raw chunk!\n", __debug__);
                 return -1;
             }
 
             do {
                 /* Inflate */
-                ret = inflate(zlib_stream, Z_NO_FLUSH);
-                if (ret == Z_NEED_DICT || ret == Z_MEM_ERROR || ret == Z_DATA_ERROR) {
+                zlib_ret = inflate(zlib_stream, Z_NO_FLUSH);
+                if (zlib_ret == Z_NEED_DICT || zlib_ret == Z_MEM_ERROR || zlib_ret == Z_DATA_ERROR) {
                     MIRAGE_DEBUG(self, MIRAGE_DEBUG_WARNING, "%s: failed to inflate part: %s!\n", __debug__, zlib_stream->msg);
                     return -1;
                 }
             } while (zlib_stream->avail_in);
         } else if (part->type == BZLIB) {
+            bz_stream *bzip2_stream = &self->priv->bzip2_stream;
+            int bz_ret;
+            gssize read_bytes;
+
             /* Reset decompress engine */
-            ret = BZ2_bzDecompressInit(bzip2_stream, 0, 0);
-            if (ret != BZ_OK) {
+            bz_ret = BZ2_bzDecompressInit(bzip2_stream, 0, 0);
+            if (bz_ret != BZ_OK) {
                 MIRAGE_DEBUG(self, MIRAGE_DEBUG_WARNING, "%s: failed to initialize decompress engine!\n", __debug__);
                 return -1;
             }
 
             /* Uncompress whole part */
-            bzip2_stream->avail_in  = part->in_length;
-            bzip2_stream->next_in   = (gchar *) self->priv->io_buffer;
+            bzip2_stream->avail_in = part->in_length;
+            bzip2_stream->next_in = (gchar *)self->priv->io_buffer;
             bzip2_stream->avail_out = self->priv->inflate_buffer_size;
-            bzip2_stream->next_out  = (gchar *) self->priv->inflate_buffer;
+            bzip2_stream->next_out = (gchar *)self->priv->inflate_buffer;
 
             /* Read some compressed data */
-            ret = mirage_filter_stream_dmg_read_raw_chunk (self, self->priv->io_buffer, part_idx);
-            if (ret != part->in_length) {
+            read_bytes = mirage_filter_stream_dmg_read_raw_chunk (self, self->priv->io_buffer, part_idx);
+            if ((gsize)read_bytes != part->in_length) {
                 MIRAGE_DEBUG(self, MIRAGE_DEBUG_WARNING, "%s: failed to read raw chunk!\n", __debug__);
                 return -1;
             }
 
             do {
                 /* Inflate */
-                ret = BZ2_bzDecompress(bzip2_stream);
-                if (ret < 0) {
-                    MIRAGE_DEBUG(self, MIRAGE_DEBUG_WARNING, "%s: failed to inflate part: %d!\n", __debug__, ret);
+                bz_ret = BZ2_bzDecompress(bzip2_stream);
+                if (bz_ret < 0) {
+                    MIRAGE_DEBUG(self, MIRAGE_DEBUG_WARNING, "%s: failed to inflate part: %d!\n", __debug__, bz_ret);
                     return -1;
                 }
             } while (bzip2_stream->avail_in);
 
             /* Uninitialize decompress engine */
-            ret = BZ2_bzDecompressEnd(bzip2_stream);
-            if (ret != BZ_OK) {
+            bz_ret = BZ2_bzDecompressEnd(bzip2_stream);
+            if (bz_ret != BZ_OK) {
                 MIRAGE_DEBUG(self, MIRAGE_DEBUG_WARNING, "%s: failed to uninitialize decompress engine!\n", __debug__);
                 return -1;
             }
         } else if (part->type == ADC) {
+            gsize read_bytes;
             gsize written_bytes;
+            gsize ret;
 
             /* Read some compressed data */
-            ret = mirage_filter_stream_dmg_read_raw_chunk (self, self->priv->io_buffer, part_idx);
-            if (ret != part->in_length) {
+            read_bytes = mirage_filter_stream_dmg_read_raw_chunk (self, self->priv->io_buffer, part_idx);
+            if ((gsize)read_bytes != part->in_length) {
                 MIRAGE_DEBUG(self, MIRAGE_DEBUG_WARNING, "%s: failed to read raw chunk!\n", __debug__);
                 return -1;
             }
 
             /* Inflate */
-            ret = (gint) adc_decompress(part->in_length, self->priv->io_buffer, part->num_sectors * DMG_SECTOR_SIZE,
-                           self->priv->inflate_buffer, &written_bytes);
+            ret = adc_decompress(part->in_length, self->priv->io_buffer, part->num_sectors * DMG_SECTOR_SIZE, self->priv->inflate_buffer, &written_bytes);
 
             g_assert (ret == part->in_length);
             g_assert (written_bytes == part->num_sectors * DMG_SECTOR_SIZE);
@@ -950,7 +973,7 @@ static gssize mirage_filter_stream_dmg_partial_read (MirageFilterStream *_self,
     /* Copy data */
     const DMG_Part *part = &self->priv->parts[part_idx];
 
-    gsize   part_size = part->num_sectors * DMG_SECTOR_SIZE;
+    gsize part_size = part->num_sectors * DMG_SECTOR_SIZE;
     guint64 part_offset = position - (part->first_sector * DMG_SECTOR_SIZE);
     count = MIN(count, part_size - part_offset);
 
@@ -969,18 +992,6 @@ static gssize mirage_filter_stream_dmg_partial_read (MirageFilterStream *_self,
 /**********************************************************************\
  *                             Object init                            *
 \**********************************************************************/
-G_DEFINE_DYNAMIC_TYPE_EXTENDED(MirageFilterStreamDmg,
-                               mirage_filter_stream_dmg,
-                               MIRAGE_TYPE_FILTER_STREAM,
-                               0,
-                               G_ADD_PRIVATE_DYNAMIC(MirageFilterStreamDmg))
-
-void mirage_filter_stream_dmg_type_register (GTypeModule *type_module)
-{
-    return mirage_filter_stream_dmg_register_type(type_module);
-}
-
-
 static void mirage_filter_stream_dmg_init (MirageFilterStreamDmg *self)
 {
     self->priv = mirage_filter_stream_dmg_get_instance_private(self);
@@ -1014,7 +1025,7 @@ static void mirage_filter_stream_dmg_finalize (GObject *gobject)
 {
     MirageFilterStreamDmg *self = MIRAGE_FILTER_STREAM_DMG(gobject);
 
-    for (gint s = 0; s < self->priv->num_streams; s++) {
+    for (guint s = 0; s < self->priv->num_streams; s++) {
         g_object_unref(self->priv->streams[s]);
     }
     g_free(self->priv->streams);
@@ -1031,7 +1042,7 @@ static void mirage_filter_stream_dmg_finalize (GObject *gobject)
     rsrc_fork_free(self->priv->rsrc_fork);
 
     /* Chain up to the parent class */
-    return G_OBJECT_CLASS(mirage_filter_stream_dmg_parent_class)->finalize(gobject);
+    G_OBJECT_CLASS(mirage_filter_stream_dmg_parent_class)->finalize(gobject);
 }
 
 static void mirage_filter_stream_dmg_class_init (MirageFilterStreamDmgClass *klass)
