@@ -1,6 +1,6 @@
 /*
  *  libMirage: GZIP filter: filter stream
- *  Copyright (C) 2012-2014 Rok Mandeljc
+ *  Copyright (C) 2012-2026 Rok Mandeljc
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -38,11 +38,11 @@ typedef struct
 } GZIP_Part;
 
 
-static const guint8 gzip_signature[2] = { 0x1F, 0x8B };
+static const guint8 gzip_signature[2] = {0x1F, 0x8B};
 
 
 /**********************************************************************\
- *                          Private structure                         *
+ *                  Object and its private structure                  *
 \**********************************************************************/
 struct _MirageFilterStreamGzipPrivate
 {
@@ -68,6 +68,20 @@ struct _MirageFilterStreamGzipPrivate
 };
 
 
+G_DEFINE_DYNAMIC_TYPE_EXTENDED(
+    MirageFilterStreamGzip,
+    mirage_filter_stream_gzip,
+    MIRAGE_TYPE_FILTER_STREAM,
+    0,
+    G_ADD_PRIVATE_DYNAMIC(MirageFilterStreamGzip)
+)
+
+void mirage_filter_stream_gzip_type_register (GTypeModule *type_module)
+{
+    mirage_filter_stream_gzip_register_type(type_module);
+}
+
+
 /**********************************************************************\
  *                           Part indexing                            *
 \**********************************************************************/
@@ -123,7 +137,7 @@ static gboolean mirage_filter_stream_gzip_append_part (MirageFilterStreamGzip *s
     self->priv->num_parts++;
 
     /* Check if we need to allocate more parts; if we do, double the
-       number of allocated parts to avoid reallocating often */
+     * number of allocated parts to avoid reallocating often */
     if (self->priv->num_parts > self->priv->allocated_parts) {
         self->priv->allocated_parts *= 2;
         self->priv->parts = g_try_renew(GZIP_Part, self->priv->parts, self->priv->allocated_parts);
@@ -154,7 +168,9 @@ static gboolean mirage_filter_stream_gzip_build_index (MirageFilterStreamGzip *s
     MirageStream *stream = mirage_filter_stream_get_underlying_stream(MIRAGE_FILTER_STREAM(self));
     z_stream *zlib_stream = &self->priv->zlib_stream;
 
-    goffset totalIn, totalOut, last;
+    goffset total_in;
+    goffset total_out;
+    goffset last;
     gint ret;
 
 
@@ -193,7 +209,7 @@ static gboolean mirage_filter_stream_gzip_build_index (MirageFilterStreamGzip *s
     }
 
     /* Inflate the input and build an index */
-    totalIn = totalOut = last = 0;
+    total_in = total_out = last = 0;
     zlib_stream->avail_out = 0;
     do {
         /* Read some compressed data */
@@ -218,13 +234,13 @@ static gboolean mirage_filter_stream_gzip_build_index (MirageFilterStreamGzip *s
             }
 
             /* Inflate until end of input or output, or until end of block */
-            totalIn += zlib_stream->avail_in;
-            totalOut += zlib_stream->avail_out;
+            total_in += zlib_stream->avail_in;
+            total_out += zlib_stream->avail_out;
 
             ret = inflate(zlib_stream, Z_BLOCK);
 
-            totalIn -= zlib_stream->avail_in;
-            totalOut -= zlib_stream->avail_out;
+            total_in -= zlib_stream->avail_in;
+            total_out -= zlib_stream->avail_out;
 
             if (ret == Z_NEED_DICT || ret == Z_MEM_ERROR || ret == Z_DATA_ERROR) {
                 g_set_error(error, MIRAGE_ERROR, MIRAGE_ERROR_STREAM_ERROR, Q_("Failed to inflate!"));
@@ -236,13 +252,13 @@ static gboolean mirage_filter_stream_gzip_build_index (MirageFilterStreamGzip *s
 
             /* If at end of block, add part entry */
             if ((zlib_stream->data_type & 128) && !(zlib_stream->data_type & 64) &&
-                (totalOut == 0 || totalOut - last > SPAN)) {
+                (total_out == 0 || total_out - last > SPAN)) {
 
-                if (!mirage_filter_stream_gzip_append_part(self, zlib_stream->data_type & 7, totalIn, totalOut, zlib_stream->avail_out, self->priv->window_buffer, error)) {
+                if (!mirage_filter_stream_gzip_append_part(self, zlib_stream->data_type & 7, total_in, total_out, zlib_stream->avail_out, self->priv->window_buffer, error)) {
                     return FALSE;
                 }
 
-                last = totalOut;
+                last = total_out;
             }
         } while (zlib_stream->avail_in);
     } while (ret != Z_STREAM_END);
@@ -259,13 +275,13 @@ static gboolean mirage_filter_stream_gzip_build_index (MirageFilterStreamGzip *s
     self->priv->parts = g_renew(GZIP_Part, self->priv->parts, self->priv->num_parts);
 
     /* Compute sizes of parts and allocate part buffer */
-    if (!mirage_filter_stream_gzip_compute_part_sizes(self, totalOut, error)) {
+    if (!mirage_filter_stream_gzip_compute_part_sizes(self, total_out, error)) {
         return FALSE;
     }
 
-    /* Store file size (= totalOut) */
-    MIRAGE_DEBUG(self, MIRAGE_DEBUG_PARSER, "%s: file size: %" G_GOFFSET_MODIFIER "d (0x%" G_GOFFSET_MODIFIER "X)\n", __debug__, totalOut, totalOut);
-    mirage_filter_stream_simplified_set_stream_length(MIRAGE_FILTER_STREAM(self), totalOut);
+    /* Store file size (= total_out) */
+    MIRAGE_DEBUG(self, MIRAGE_DEBUG_PARSER, "%s: file size: %" G_GOFFSET_MODIFIER "d (0x%" G_GOFFSET_MODIFIER "X)\n", __debug__, total_out, total_out);
+    mirage_filter_stream_simplified_set_stream_length(MIRAGE_FILTER_STREAM(self), total_out);
 
     MIRAGE_DEBUG(self, MIRAGE_DEBUG_PARSER, "%s: index building completed\n", __debug__);
 
@@ -471,18 +487,6 @@ static gssize mirage_filter_stream_gzip_partial_read (MirageFilterStream *_self,
 /**********************************************************************\
  *                             Object init                            *
 \**********************************************************************/
-G_DEFINE_DYNAMIC_TYPE_EXTENDED(MirageFilterStreamGzip,
-                               mirage_filter_stream_gzip,
-                               MIRAGE_TYPE_FILTER_STREAM,
-                               0,
-                               G_ADD_PRIVATE_DYNAMIC(MirageFilterStreamGzip))
-
-void mirage_filter_stream_gzip_type_register (GTypeModule *type_module)
-{
-    return mirage_filter_stream_gzip_register_type(type_module);
-}
-
-
 static void mirage_filter_stream_gzip_init (MirageFilterStreamGzip *self)
 {
     self->priv = mirage_filter_stream_gzip_get_instance_private(self);
@@ -519,7 +523,7 @@ static void mirage_filter_stream_gzip_finalize (GObject *gobject)
     inflateEnd(&self->priv->zlib_stream);
 
     /* Chain up to the parent class */
-    return G_OBJECT_CLASS(mirage_filter_stream_gzip_parent_class)->finalize(gobject);
+    G_OBJECT_CLASS(mirage_filter_stream_gzip_parent_class)->finalize(gobject);
 }
 
 static void mirage_filter_stream_gzip_class_init (MirageFilterStreamGzipClass *klass)
