@@ -1,6 +1,6 @@
 /*
  *  libMirage: XZ filter: filter stream
- *  Copyright (C) 2012-2014 Rok Mandeljc
+ *  Copyright (C) 2012-2026 Rok Mandeljc
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,11 +25,11 @@
 #define MAX_BLOCK_SIZE 10485760 /* For performance reasons, we support only 10 MB blocks and smaller */
 
 
-static const guint8 xz_signature[6] = { 0xFD, '7', 'z', 'X', 'Z', 0x00 };
+static const guint8 xz_signature[6] = {0xFD, '7', 'z', 'X', 'Z', 0x00};
 
 
 /**********************************************************************\
- *                          Private structure                         *
+ *                  Object and its private structure                  *
 \**********************************************************************/
 struct _MirageFilterStreamXzPrivate
 {
@@ -38,7 +38,7 @@ struct _MirageFilterStreamXzPrivate
     gint io_buffer_size;
 
     /* Block (inflate) buffer */
-    gint cached_block_number;
+    guint cached_block_number;
     guint8 *block_buffer;
     gint block_buffer_size;
 
@@ -49,6 +49,21 @@ struct _MirageFilterStreamXzPrivate
     lzma_index *index;
 };
 
+
+G_DEFINE_DYNAMIC_TYPE_EXTENDED(
+    MirageFilterStreamXz,
+    mirage_filter_stream_xz,
+    MIRAGE_TYPE_FILTER_STREAM,
+    0,
+    G_ADD_PRIVATE_DYNAMIC(MirageFilterStreamXz)
+)
+
+void mirage_filter_stream_xz_type_register (GTypeModule *type_module)
+{
+    mirage_filter_stream_xz_register_type(type_module);
+}
+
+
 static gboolean mirage_filter_stream_xz_reallocate_read_buffer (MirageFilterStreamXz *self, gint size, GError **error)
 {
     self->priv->io_buffer = g_try_realloc(self->priv->io_buffer, size);
@@ -152,7 +167,7 @@ static gboolean mirage_filter_stream_xz_read_index (MirageFilterStreamXz *self,
         return FALSE;
     }
 
-    if (mirage_stream_read(stream, self->priv->io_buffer, self->priv->footer.backward_size, NULL) != self->priv->footer.backward_size) {
+    if ((gsize)mirage_stream_read(stream, self->priv->io_buffer, self->priv->footer.backward_size, NULL) != self->priv->footer.backward_size) {
         g_set_error(error, MIRAGE_ERROR, MIRAGE_ERROR_STREAM_ERROR, Q_("Failed to read stream's index!"));
         return FALSE;
     }
@@ -306,7 +321,7 @@ static gssize mirage_filter_stream_xz_partial_read (MirageFilterStream *_self, v
         lzma_block block;
 
         guint8 value;
-        gint ret;
+        guint ret;
 
         MIRAGE_DEBUG(self, MIRAGE_DEBUG_STREAM, "%s: block not cached, reading...\n", __debug__);
 
@@ -399,18 +414,6 @@ static gssize mirage_filter_stream_xz_partial_read (MirageFilterStream *_self, v
 /**********************************************************************\
  *                             Object init                            *
 \**********************************************************************/
-G_DEFINE_DYNAMIC_TYPE_EXTENDED(MirageFilterStreamXz,
-                               mirage_filter_stream_xz,
-                               MIRAGE_TYPE_FILTER_STREAM,
-                               0,
-                               G_ADD_PRIVATE_DYNAMIC(MirageFilterStreamXz))
-
-void mirage_filter_stream_xz_type_register (GTypeModule *type_module)
-{
-    return mirage_filter_stream_xz_register_type(type_module);
-}
-
-
 static void mirage_filter_stream_xz_init (MirageFilterStreamXz *self)
 {
     self->priv = mirage_filter_stream_xz_get_instance_private(self);
@@ -441,7 +444,7 @@ static void mirage_filter_stream_xz_finalize (GObject *gobject)
     g_free(self->priv->block_buffer);
 
     /* Chain up to the parent class */
-    return G_OBJECT_CLASS(mirage_filter_stream_xz_parent_class)->finalize(gobject);
+    G_OBJECT_CLASS(mirage_filter_stream_xz_parent_class)->finalize(gobject);
 }
 
 static void mirage_filter_stream_xz_class_init (MirageFilterStreamXzClass *klass)
