@@ -1,6 +1,6 @@
 /*
  *  libMirage: CUE image
- *  Copyright (C) 2006-2014 Rok Mandeljc
+ *  Copyright (C) 2006-2026 Rok Mandeljc
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifndef __IMAGE_CUE_H__
-#define __IMAGE_CUE_H__
+#pragma once
 
 #include "mirage/config.h"
 #include <mirage/mirage.h>
@@ -26,5 +25,3 @@
 #include <glib/gi18n-lib.h>
 
 #include "parser.h"
-
-#endif /* __IMAGE_CUE_H__ */
