@@ -1,6 +1,6 @@
 /*
  *  libMirage: readcd image: parser
- *  Copyright (C) 2011-2014 Rok Mandeljc
+ *  Copyright (C) 2011-2026 Rok Mandeljc
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,9 +23,10 @@
 
 
 /**********************************************************************\
- *                          Private structure                         *
+ *                  Object and its private structure                  *
 \**********************************************************************/
-struct _MirageParserReadcdPrivate {
+struct _MirageParserReadcdPrivate
+{
     MirageDisc *disc;
 
     gint cur_lba;
@@ -42,6 +43,20 @@ struct _MirageParserReadcdPrivate {
 };
 
 
+G_DEFINE_DYNAMIC_TYPE_EXTENDED(
+    MirageParserReadcd,
+    mirage_parser_readcd,
+    MIRAGE_TYPE_PARSER,
+    0,
+    G_ADD_PRIVATE_DYNAMIC(MirageParserReadcd)
+)
+
+void mirage_parser_readcd_type_register (GTypeModule *type_module)
+{
+    mirage_parser_readcd_register_type(type_module);
+}
+
+
 static gboolean mirage_parser_readcd_is_file_valid (MirageParserReadcd *self, MirageStream *stream, GError **error)
 {
     guint64 file_size;
@@ -56,7 +71,7 @@ static gboolean mirage_parser_readcd_is_file_valid (MirageParserReadcd *self, Mi
     }
 
     /* First 4 bytes of TOC are its header; and first 2 bytes of that indicate
-       the length */
+     * the length */
     MIRAGE_DEBUG(self, MIRAGE_DEBUG_IMAGE_ID, "%s: reading 4-byte header...\n", __debug__);
     mirage_stream_seek(stream, 0, G_SEEK_SET, NULL);
     if (mirage_stream_read(stream, &toc_len, sizeof(toc_len), NULL) != sizeof(toc_len)) {
@@ -66,7 +81,7 @@ static gboolean mirage_parser_readcd_is_file_valid (MirageParserReadcd *self, Mi
     toc_len = GUINT16_FROM_BE(toc_len);
 
     /* Does TOC length match? (the TOC file actually contains TOC plus two bytes
-       that indicate sector types) */
+     * that indicate sector types) */
     mirage_stream_seek(stream, 0, G_SEEK_END, NULL);
     file_size = mirage_stream_tell(stream);
 
@@ -75,9 +90,12 @@ static gboolean mirage_parser_readcd_is_file_valid (MirageParserReadcd *self, Mi
     MIRAGE_DEBUG(self, MIRAGE_DEBUG_IMAGE_ID, "%s:  actual data file size: %" G_GINT64_MODIFIER "d\n", __debug__, file_size);
 
     /* readcd from cdrdtools appears to pad odd TOC lengths to make them
-       even, whereas readcd from cdrkit does not. So we account for both
-       cases. */
-    if ((file_size == 2 + toc_len + 2) || (file_size == 2 + toc_len + 3)) {
+     * even, whereas readcd from cdrkit does not. So we account for both
+     * cases. */
+    if (
+        (file_size == (guint16)(2 + toc_len + 2)) ||
+        (file_size == (guint16)(2 + toc_len + 3))
+    ) {
         return TRUE;
     }
 
@@ -282,7 +300,7 @@ static gboolean mirage_parser_readcd_parse_toc (MirageParserReadcd *self, Mirage
     const gchar *suffix;
 
     /* NOTE: the mirage_parser_readcd_is_file_valid() check guarantees that the
-       image filename has a valid suffix... */
+     * image filename has a valid suffix... */
     tmp_data_filename = g_strdup(self->priv->toc_filename);
     suffix = mirage_helper_get_suffix(tmp_data_filename);
     tmp_data_filename[suffix-tmp_data_filename] = '\0'; /* Skip the suffix */
@@ -427,7 +445,7 @@ static MirageDisc *mirage_parser_readcd_load_image (MirageParser *_self, MirageS
 
     if (succeeded) {
         /* If it's a multisession disc, fix up the lead-in/lead-out lengths
-           (NOTE: last session is left out for readibility; but it's irrelevant) */
+         * (NOTE: last session is left out for readibility; but it's irrelevant) */
         gint num_sessions = mirage_disc_get_number_of_sessions(self->priv->disc);
         for (gint i = 0; i < num_sessions - 1; i++) {
             MirageSession *session = mirage_disc_get_session_by_index(self->priv->disc, i, NULL);
@@ -468,18 +486,6 @@ static MirageDisc *mirage_parser_readcd_load_image (MirageParser *_self, MirageS
 /**********************************************************************\
  *                             Object init                            *
 \**********************************************************************/
-G_DEFINE_DYNAMIC_TYPE_EXTENDED(MirageParserReadcd,
-                               mirage_parser_readcd,
-                               MIRAGE_TYPE_PARSER,
-                               0,
-                               G_ADD_PRIVATE_DYNAMIC(MirageParserReadcd))
-
-void mirage_parser_readcd_type_register (GTypeModule *type_module)
-{
-    return mirage_parser_readcd_register_type(type_module);
-}
-
-
 static void mirage_parser_readcd_init (MirageParserReadcd *self)
 {
     self->priv = mirage_parser_readcd_get_instance_private(self);
@@ -505,7 +511,7 @@ static void mirage_parser_readcd_dispose (GObject *gobject)
     }
 
     /* Chain up to the parent class */
-    return G_OBJECT_CLASS(mirage_parser_readcd_parent_class)->dispose(gobject);
+    G_OBJECT_CLASS(mirage_parser_readcd_parent_class)->dispose(gobject);
 }
 
 static void mirage_parser_readcd_finalize (GObject *gobject)
@@ -515,7 +521,7 @@ static void mirage_parser_readcd_finalize (GObject *gobject)
     g_free(self->priv->data_filename);
 
     /* Chain up to the parent class */
-    return G_OBJECT_CLASS(mirage_parser_readcd_parent_class)->finalize(gobject);
+    G_OBJECT_CLASS(mirage_parser_readcd_parent_class)->finalize(gobject);
 }
 
 static void mirage_parser_readcd_class_init (MirageParserReadcdClass *klass)
