@@ -1,6 +1,6 @@
 /*
  *  libMirage: TOC image
- *  Copyright (C) 2006-2014 Rok Mandeljc
+ *  Copyright (C) 2006-2026 Rok Mandeljc
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifndef __IMAGE_TOC_H__
-#define __IMAGE_TOC_H__
+#pragma once
 
 #include "mirage/config.h"
 #include <mirage/mirage.h>
@@ -28,10 +27,3 @@
 
 #include "parser.h"
 #include "writer.h"
-
-
-G_BEGIN_DECLS
-
-G_END_DECLS
-
-#endif /* __IMAGE_TOC_H__ */
