@@ -1,6 +1,6 @@
 /*
  *  libMirage: disc
- *  Copyright (C) 2006-2014 Rok Mandeljc
+ *  Copyright (C) 2006-2026 Rok Mandeljc
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -37,6 +37,7 @@
 
 #include "mirage/config.h"
 #include "mirage/mirage.h"
+#include "mirage/utils-private.h"
 
 #include <glib/gi18n-lib.h>
 
@@ -44,7 +45,7 @@
 
 
 /**********************************************************************\
- *                          Private structure                         *
+ *                  Object and its private structure                  *
 \**********************************************************************/
 struct _MirageDiscPrivate
 {
@@ -53,9 +54,9 @@ struct _MirageDiscPrivate
     MirageMediumType medium_type;
 
     /* Layout settings */
-    gint start_sector;  /* Start sector */
+    gint start_sector; /* Start sector */
     gint first_session; /* Number of the first session on disc */
-    gint first_track;   /* Number of the first track on disc */
+    gint first_track; /* Number of the first track on disc */
     gint length;
 
     GHashTable *disc_structures;
@@ -73,6 +74,9 @@ struct _MirageDiscPrivate
 };
 
 
+G_DEFINE_TYPE_WITH_PRIVATE(MirageDisc, mirage_disc, MIRAGE_TYPE_OBJECT)
+
+
 /**********************************************************************\
  *                          Private functions                         *
 \**********************************************************************/
@@ -126,35 +130,35 @@ static void mirage_disc_commit_bottomup_change (MirageDisc *self)
 
 static void mirage_disc_session_layout_changed_handler (MirageDisc *self, MirageSession *session)
 {
-    MIRAGE_DEBUG(self, MIRAGE_DEBUG_DISC, "%s: start\n", __debug__);
+    MIRAGE_DEBUG(self, MIRAGE_DEBUG_DISC, "%s: %s: start\n", __debug__, __func__);
 
     /* If session has been emptied, remove it (it'll do bottom-up change automatically);
-       otherwise, signal bottom-up change */
+     * otherwise, signal bottom-up change */
     if (!mirage_session_get_number_of_tracks(session)) {
         mirage_disc_remove_session(self, session);
     } else {
         mirage_disc_commit_bottomup_change(self);
     }
 
-    MIRAGE_DEBUG(self, MIRAGE_DEBUG_DISC, "%s: end\n", __debug__);
+    MIRAGE_DEBUG(self, MIRAGE_DEBUG_DISC, "%s: %s: end\n", __debug__, __func__);
 }
 
 static void mirage_disc_remove_session (MirageDisc *self, MirageSession *session)
 {
-    MIRAGE_DEBUG(self, MIRAGE_DEBUG_DISC, "%s: start\n", __debug__);
+    MIRAGE_DEBUG(self, MIRAGE_DEBUG_DISC, "%s: %s: start\n", __debug__, __func__);
 
     /* Disconnect signal handler (find it by handler function and user data) */
-    g_signal_handlers_disconnect_by_func(session, mirage_disc_session_layout_changed_handler, self);
+    mirage_signal_handlers_disconnect_by_func(session, G_CALLBACK(mirage_disc_session_layout_changed_handler), self);
 
     /* Remove session from list and unref it */
     self->priv->sessions_list = g_list_remove(self->priv->sessions_list, session);
     g_object_unref(session);
 
     /* Bottom-up change */
-    MIRAGE_DEBUG(self, MIRAGE_DEBUG_DISC, "%s: committing bottom-up change\n", __debug__);
+    MIRAGE_DEBUG(self, MIRAGE_DEBUG_DISC, "%s: %s: committing bottom-up change\n", __debug__, __func__);
     mirage_disc_commit_bottomup_change(self);
 
-    MIRAGE_DEBUG(self, MIRAGE_DEBUG_DISC, "%s: end\n", __debug__);
+    MIRAGE_DEBUG(self, MIRAGE_DEBUG_DISC, "%s: %s: end\n", __debug__, __func__);
 }
 
 static gint sort_sessions_by_number (MirageSession *session1, MirageSession *session2)
@@ -480,7 +484,7 @@ void mirage_disc_add_session_by_index (MirageDisc *self, gint index, MirageSessi
     self->priv->sessions_list = g_list_insert(self->priv->sessions_list, session, index);
 
     /* Connect session modified signal */
-    g_signal_connect_swapped(session, "layout-changed", (GCallback)mirage_disc_session_layout_changed_handler, self);
+    g_signal_connect_swapped(session, "layout-changed", G_CALLBACK(mirage_disc_session_layout_changed_handler), self);
 
     /* Bottom-up change */
     mirage_disc_commit_bottomup_change(self);
@@ -491,7 +495,7 @@ void mirage_disc_add_session_by_index (MirageDisc *self, gint index, MirageSessi
  * @self: a #MirageDisc
  * @number: (in): session number for the added session
  * @session: (in) (transfer full): a #MirageSession to be added
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Adds session to disc layout.
  *
@@ -528,7 +532,7 @@ gboolean mirage_disc_add_session_by_number (MirageDisc *self, gint number, Mirag
     self->priv->sessions_list = g_list_insert_sorted(self->priv->sessions_list, session, (GCompareFunc)sort_sessions_by_number);
 
     /* Connect session modified signal */
-    g_signal_connect_swapped(session, "layout-changed", (GCallback)mirage_disc_session_layout_changed_handler, self);
+    g_signal_connect_swapped(session, "layout-changed", G_CALLBACK(mirage_disc_session_layout_changed_handler), self);
 
     /* Bottom-up change */
     mirage_disc_commit_bottomup_change(self);
@@ -540,7 +544,7 @@ gboolean mirage_disc_add_session_by_number (MirageDisc *self, gint number, Mirag
  * mirage_disc_remove_session_by_index:
  * @self: a #MirageDisc
  * @index: (in): index of session to be removed
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Removes session from disc layout.
  *
@@ -573,7 +577,7 @@ gboolean mirage_disc_remove_session_by_index (MirageDisc *self, gint index, GErr
  * mirage_disc_remove_session_by_number:
  * @self: a #MirageDisc
  * @number: (in): session number of session to be removed
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Removes session from disc layout.
  *
@@ -623,7 +627,7 @@ void mirage_disc_remove_session_by_object (MirageDisc *self, MirageSession *sess
  * mirage_disc_get_session_by_index:
  * @self: a #MirageDisc
  * @index: (in): index of session to be retrieved
- * @error: (out) (allow-none):location to store error, or %NULL
+ * @error: (out) (optional):location to store error, or %NULL
  *
  * Retrieves session by index. If @index is negative, sessions from the end of
  * layout are retrieved (e.g. -1 is for last session, -2 for second-to-last
@@ -663,7 +667,7 @@ MirageSession *mirage_disc_get_session_by_index (MirageDisc *self, gint index, G
  * mirage_disc_get_session_by_number:
  * @self: a #MirageDisc
  * @number: (in): number of session to be retrieved
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Retrieves session by session number.
  *
@@ -700,7 +704,7 @@ MirageSession *mirage_disc_get_session_by_number (MirageDisc *self, gint session
  * mirage_disc_get_session_by_address:
  * @self: a #MirageDisc
  * @address: (in): address belonging to session to be retrieved
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Retrieves session by address. @address must be valid (disc-relative) sector
  * address that is part of the session to be retrieved (i.e. lying between session's
@@ -744,7 +748,7 @@ MirageSession *mirage_disc_get_session_by_address (MirageDisc *self, gint addres
  * mirage_disc_get_session_by_track:
  * @self: a #MirageDisc
  * @track: (in): number of track belonging to session to be retrieved
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Retrieves session by track number. @track must be valid track number of track
  * that is part of the session.
@@ -787,8 +791,8 @@ MirageSession *mirage_disc_get_session_by_track (MirageDisc *self, gint track_nu
 /**
  * mirage_disc_enumerate_sessions:
  * @self: a #MirageDisc
- * @func: (in) (scope call): callback function
- * @user_data: (in) (closure): data to be passed to callback function
+ * @func: (in) (scope call) (closure user_data): callback function
+ * @user_data: (in) (nullable): data to be passed to callback function
  *
  * Iterates over sessions list, calling @func for each session in the layout.
  *
@@ -812,7 +816,7 @@ gboolean mirage_disc_enumerate_sessions (MirageDisc *self, MirageEnumSessionCall
  * mirage_disc_get_session_before:
  * @self: a #MirageDisc
  * @session: (in): a session
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Retrieves session that comes before @session.
  *
@@ -827,7 +831,7 @@ MirageSession *mirage_disc_get_session_before (MirageDisc *self, MirageSession *
     /* Get index of given session in the list */
     index = g_list_index(self->priv->sessions_list, session);
     if (index == -1) {
-        g_set_error(error, MIRAGE_ERROR, MIRAGE_ERROR_DISC_ERROR, Q_("Session %p is not in disc layout!"), session);
+        g_set_error(error, MIRAGE_ERROR, MIRAGE_ERROR_DISC_ERROR, Q_("Session %p is not in disc layout!"), (void *)session);
         return NULL;
     }
 
@@ -836,7 +840,7 @@ MirageSession *mirage_disc_get_session_before (MirageDisc *self, MirageSession *
         return mirage_disc_get_session_by_index(self, index - 1, error);
     }
 
-    g_set_error(error, MIRAGE_ERROR, MIRAGE_ERROR_DISC_ERROR, Q_("Session before session %p not found!"), session);
+    g_set_error(error, MIRAGE_ERROR, MIRAGE_ERROR_DISC_ERROR, Q_("Session before session %p not found!"), (void *)session);
     return NULL;
 }
 
@@ -844,7 +848,7 @@ MirageSession *mirage_disc_get_session_before (MirageDisc *self, MirageSession *
  * mirage_disc_get_session_after:
  * @self: a #MirageDisc
  * @session: (in): a session
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Retrieves session that comes after @session.
  *
@@ -859,7 +863,7 @@ MirageSession *mirage_disc_get_session_after (MirageDisc *self, MirageSession *s
     /* Get index of given session in the list */
     index = g_list_index(self->priv->sessions_list, session);
     if (index == -1) {
-        g_set_error(error, MIRAGE_ERROR, MIRAGE_ERROR_DISC_ERROR, Q_("Session %p is not in disc layout!"), session);
+        g_set_error(error, MIRAGE_ERROR, MIRAGE_ERROR_DISC_ERROR, Q_("Session %p is not in disc layout!"), (void *)session);
         return NULL;
     }
 
@@ -869,7 +873,7 @@ MirageSession *mirage_disc_get_session_after (MirageDisc *self, MirageSession *s
         return mirage_disc_get_session_by_index(self, index + 1, error);
     }
 
-    g_set_error(error, MIRAGE_ERROR, MIRAGE_ERROR_DISC_ERROR, Q_("Session after session %p not found!"), session);
+    g_set_error(error, MIRAGE_ERROR, MIRAGE_ERROR_DISC_ERROR, Q_("Session after session %p not found!"), (void *)session);
     return NULL;
 }
 
@@ -893,7 +897,7 @@ gint mirage_disc_get_number_of_tracks (MirageDisc *self)
  * @self: a #MirageDisc
  * @index: (in): index at which track should be added
  * @track: (in) (transfer full): a #MirageTrack to be added
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Adds track to disc layout.
  *
@@ -921,7 +925,7 @@ gboolean mirage_disc_add_track_by_index (MirageDisc *self, gint index, MirageTra
     gint count;
 
     /* If disc layout is empty (if there are no sessions), we should create
-       a session... and then track will be added to this one */
+     * a session... and then track will be added to this one */
     if (!mirage_disc_get_number_of_sessions(self)) {
         MirageSession *session = g_object_new(MIRAGE_TYPE_SESSION, NULL);
         mirage_disc_add_session_by_index(self, 0, session);
@@ -943,7 +947,7 @@ gboolean mirage_disc_add_track_by_index (MirageDisc *self, gint index, MirageTra
     }
 
     /* Iterate over all the sessions and determine the one where track with
-       desired index should be in */
+     * desired index should be in */
     count = 0;
     for (GList *entry = self->priv->sessions_list; entry; entry = entry->next) {
         MirageSession *session = entry->data;
@@ -968,7 +972,7 @@ gboolean mirage_disc_add_track_by_index (MirageDisc *self, gint index, MirageTra
  * @self: a #MirageDisc
  * @number: (in): track number for the added track
  * @track: (in) (transfer full): a #MirageTrack to be added
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Adds track to disc layout.
  *
@@ -1007,12 +1011,12 @@ gboolean mirage_disc_add_track_by_number (MirageDisc *self, gint number, MirageT
 
     if (!mirage_disc_get_number_of_sessions(self)) {
         /* If disc layout is empty (if there are no sessions), we should create
-           a session... and then track will be added to this one */
+         * a session... and then track will be added to this one */
         session = g_object_new(MIRAGE_TYPE_SESSION, NULL);
         mirage_disc_add_session_by_index(self, 0, session);
     } else if (number > last_number) {
         /* If track number surpasses the number of last track on disc, then it
-           means we need to add the track into last session */
+         * means we need to add the track into last session */
         session = mirage_disc_get_session_by_index(self, -1, error);
     } else {
         /* Try to get the session by track number */
@@ -1034,7 +1038,7 @@ gboolean mirage_disc_add_track_by_number (MirageDisc *self, gint number, MirageT
  * mirage_disc_remove_track_by_index:
  * @self: a #MirageDisc
  * @index: (in): index of track to be removed
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Removes track from disc layout.
  *
@@ -1078,7 +1082,7 @@ gboolean mirage_disc_remove_track_by_index (MirageDisc *self, gint index, GError
  * mirage_disc_remove_track_by_number:
  * @self: a #MirageDisc
  * @number: (in): track number of track to be removed
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Removes track from disc layout.
  *
@@ -1128,7 +1132,7 @@ gboolean mirage_disc_remove_track_by_number (MirageDisc *self, gint number, GErr
  * mirage_disc_get_track_by_index:
  * @self: a #MirageDisc
  * @index: (in): index of track to be retrieved
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Retrieves track by index. The function attempts to find appropriate session
  * by iterating over sessions list and verifying index ranges, then retrieves
@@ -1180,7 +1184,7 @@ MirageTrack *mirage_disc_get_track_by_index (MirageDisc *self, gint index, GErro
  * mirage_disc_get_track_by_number:
  * @self: a #MirageDisc
  * @number: (in): track number of track to be retrieved
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Retrieves track by track number. The function attempts to find appropriate session
  * using mirage_disc_get_session_by_track(), then retrieves the track using
@@ -1214,7 +1218,7 @@ MirageTrack *mirage_disc_get_track_by_number (MirageDisc *self, gint number, GEr
  * mirage_disc_get_track_by_address:
  * @self: a #MirageDisc
  * @address: (in): address belonging to track to be retrieved
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Retrieves track by address. @address must be valid (disc-relative) sector
  * address that is part of the track to be retrieved (i.e. lying between track's
@@ -1275,7 +1279,7 @@ void mirage_disc_set_disc_structure (MirageDisc *self, gint layer, gint type, co
     }
 
     /* Store the data in a GByteArray (FIXME someday, we'll migrate
-       this to GBytes, which requires GLib 2.32) */
+     * this to GBytes, which requires GLib 2.32) */
     array = g_byte_array_new();
     array = g_byte_array_append(array, data, len);
 
@@ -1287,9 +1291,9 @@ void mirage_disc_set_disc_structure (MirageDisc *self, gint layer, gint type, co
  * @self: a #MirageDisc
  * @layer: (in): disc layer
  * @type: (in): disc structure type
- * @data: (out) (transfer none) (allow-none) (array length=len): location to store buffer containing disc structure data, or %NULL
- * @len: (out) (allow-none): location to store data length, or %NULL
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @data: (out) (transfer none) (optional) (array length=len): location to store buffer containing disc structure data, or %NULL
+ * @len: (out) (optional): location to store data length, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Retrieves disc structure of type @type from layer @layer. The pointer to buffer
  * containing the disc structure is stored in @data; the buffer belongs to the
@@ -1341,7 +1345,7 @@ gboolean mirage_disc_get_disc_structure (MirageDisc *self, gint layer, gint type
  * mirage_disc_get_sector:
  * @self: a #MirageDisc
  * @address: (in): sector address
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Retrieves sector object representing sector at sector address @address.
  *
@@ -1374,7 +1378,7 @@ MirageSector *mirage_disc_get_sector (MirageDisc *self, gint address, GError **e
  * mirage_disc_put_sector:
  * @self: a #MirageDisc
  * @sector: (in): a #MirageSector representing sector to be written
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Writes the @sector to disc.
  *
@@ -1396,8 +1400,8 @@ gboolean mirage_disc_put_sector (MirageDisc *self, MirageSector *sector, GError
     track = mirage_disc_get_track_by_address(self, address, NULL);
     if (!track) {
         /* We also allow data to be appended to the last track; for this,
-           however, the sector's address is allowed to be one more than
-           the last valid address of the last layout... */
+         * however, the sector's address is allowed to be one more than
+         * the last valid address of the last layout... */
         track = mirage_disc_get_track_by_address(self, address - 1, error);
         if (!track) {
             return FALSE;
@@ -1437,7 +1441,7 @@ void mirage_disc_set_dpm_data (MirageDisc *self, gint start, gint resolution, gi
     self->priv->dpm_resolution = resolution;
     self->priv->dpm_num_entries = num_entries;
     /* Allocate and copy data only if number of entries is positive (otherwise
-       the data is simply reset) */
+     * the data is simply reset) */
     if (self->priv->dpm_num_entries > 0) {
         self->priv->dpm_data = g_new0(guint32, self->priv->dpm_num_entries);
         memcpy(self->priv->dpm_data, data, sizeof(guint32)*self->priv->dpm_num_entries);
@@ -1447,10 +1451,10 @@ void mirage_disc_set_dpm_data (MirageDisc *self, gint start, gint resolution, gi
 /**
  * mirage_disc_get_dpm_data:
  * @self: a #MirageDisc
- * @start: (out) (allow-none): location to store DPM start sector, or %NULL
- * @resolution: (out) (allow-none): location to store DPM data resolution, or %NULL
- * @num_entries: (out) (allow-none): location to store number of DPM entries, or %NULL
- * @data: (out) (allow-none) (array length=num_entries) (transfer none): location to store pointer to buffer containing DPM data, or %NULL
+ * @start: (out) (optional): location to store DPM start sector, or %NULL
+ * @resolution: (out) (optional): location to store DPM data resolution, or %NULL
+ * @num_entries: (out) (optional): location to store number of DPM entries, or %NULL
+ * @data: (out) (optional) (array length=num_entries) (transfer none): location to store pointer to buffer containing DPM data, or %NULL
  *
  * Retrieves DPM data for disc. The pointer to buffer containing DPM data entries
  * is stored in @data; the buffer belongs to object and therefore should not be
@@ -1476,9 +1480,9 @@ void mirage_disc_get_dpm_data (MirageDisc *self, gint *start, gint *resolution,
  * mirage_disc_get_dpm_data_for_sector:
  * @self: a #MirageDisc
  * @address: (in): address of sector to retrieve DPM data for
- * @angle: (out) (allow-none): location to store sector angle, or %NULL
- * @density: (out) (allow-none): location to store sector density, or %NULL
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @angle: (out) (optional): location to store sector angle, or %NULL
+ * @density: (out) (optional): location to store sector density, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Retrieves DPM data for sector at address @address. Two pieces of data can be
  * retrieved; first one is sector angle, expressed in rotations (i.e. 0.25 would
@@ -1503,7 +1507,7 @@ gboolean mirage_disc_get_dpm_data_for_sector (MirageDisc *self, gint address, gd
     rel_address = address - self->priv->dpm_start;
 
     /* Check if relative address is out of range (account for possibility of
-       sectors lying behind last DPM entry) */
+     * sectors lying behind last DPM entry) */
     if (rel_address < 0 || rel_address >= (self->priv->dpm_num_entries+1)*self->priv->dpm_resolution) {
         g_set_error(error, MIRAGE_ERROR, MIRAGE_ERROR_DISC_ERROR, Q_("Sector address %d out of range!"), address);
         return FALSE;
@@ -1513,25 +1517,25 @@ gboolean mirage_disc_get_dpm_data_for_sector (MirageDisc *self, gint address, gd
     idx_bottom = rel_address/self->priv->dpm_resolution;
 
     /* Three possibilities; in all three cases we calculate tmp_density as the
-       difference between top and bottom angle, converted to rotations and
-       divided by resolution. Because our DPM data entries don't contain entry
-       for address 0, but start with 1*dpm_resolution instead, we'll have to
-       readjust bottom index... (actual entry index is bottom index minus 1) */
+     * difference between top and bottom angle, converted to rotations and
+     * divided by resolution. Because our DPM data entries don't contain entry
+     * for address 0, but start with 1*dpm_resolution instead, we'll have to
+     * readjust bottom index... (actual entry index is bottom index minus 1) */
     if (idx_bottom == 0) {
         /* If bottom index is 0, we have address between 0 and 1*dpm_resolution;
-           this means bottom angle is 0 and top angle is first DPM entry (with
-           index 0, which equals idx_bottom). */
+         * this means bottom angle is 0 and top angle is first DPM entry (with
+         * index 0, which equals idx_bottom). */
         tmp_density = self->priv->dpm_data[idx_bottom];
     } else if (idx_bottom == self->priv->dpm_num_entries) {
         /* Special case; we allow addresses past last DPM entry's address, but
-           only as long as they don't get past the address that would belong to
-           next DPM entry. This is because resolution is not a factor of disc
-           length and therefore some sectors might remain past last DPM entry.
-           In this case, we use angles from previous interval. */
+         * only as long as they don't get past the address that would belong to
+         * next DPM entry. This is because resolution is not a factor of disc
+         * length and therefore some sectors might remain past last DPM entry.
+         * In this case, we use angles from previous interval. */
         tmp_density = (self->priv->dpm_data[idx_bottom-1] - self->priv->dpm_data[idx_bottom-2]);
     } else {
         /* Regular case; top angle minus bottom angle, where we need to decrease
-           idx_bottom by one to account for index difference as described above */
+         * idx_bottom by one to account for index difference as described above */
         tmp_density = (self->priv->dpm_data[idx_bottom] - self->priv->dpm_data[idx_bottom-1]);
     }
     tmp_density /= 256.0; /* Convert hex degrees into rotations */
@@ -1540,7 +1544,7 @@ gboolean mirage_disc_get_dpm_data_for_sector (MirageDisc *self, gint address, gd
     if (angle) {
         tmp_angle = (rel_address - idx_bottom*self->priv->dpm_resolution)*tmp_density; /* Angle difference */
         /* Add base angle, but only if it's not 0 (which is the case when
-           idx_bottom is 0) */
+         * idx_bottom is 0) */
         if (idx_bottom > 0) {
             tmp_angle += self->priv->dpm_data[idx_bottom-1]/256.0; /* Add bottom angle */
         }
@@ -1561,9 +1565,6 @@ gboolean mirage_disc_get_dpm_data_for_sector (MirageDisc *self, gint address, gd
 /**********************************************************************\
  *                             Object init                            *
 \**********************************************************************/
-G_DEFINE_TYPE_WITH_PRIVATE(MirageDisc, mirage_disc, MIRAGE_TYPE_OBJECT)
-
-
 static void mirage_disc_init (MirageDisc *self)
 {
     self->priv = mirage_disc_get_instance_private(self);
@@ -1592,7 +1593,7 @@ static void mirage_disc_dispose (GObject *gobject)
         if (entry->data) {
             MirageSession *session = entry->data;
             /* Disconnect signal handler and unref */
-            g_signal_handlers_disconnect_by_func(session, mirage_disc_session_layout_changed_handler, self);
+            mirage_signal_handlers_disconnect_by_func(session, G_CALLBACK(mirage_disc_session_layout_changed_handler), self);
             g_object_unref(session);
 
             entry->data = NULL;
@@ -1606,7 +1607,7 @@ static void mirage_disc_dispose (GObject *gobject)
     }
 
     /* Chain up to the parent class */
-    return G_OBJECT_CLASS(mirage_disc_parent_class)->dispose(gobject);
+    G_OBJECT_CLASS(mirage_disc_parent_class)->dispose(gobject);
 }
 
 static void mirage_disc_finalize (GObject *gobject)
@@ -1620,7 +1621,7 @@ static void mirage_disc_finalize (GObject *gobject)
     g_free(self->priv->dpm_data);
 
     /* Chain up to the parent class */
-    return G_OBJECT_CLASS(mirage_disc_parent_class)->finalize(gobject);
+    G_OBJECT_CLASS(mirage_disc_parent_class)->finalize(gobject);
 }
 
 static void mirage_disc_class_init (MirageDiscClass *klass)
