@@ -1,6 +1,6 @@
 /*
  *  libMirage: session
- *  Copyright (C) 2006-2014 Rok Mandeljc
+ *  Copyright (C) 2006-2026 Rok Mandeljc
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -32,6 +32,7 @@
 
 #include "mirage/config.h"
 #include "mirage/mirage.h"
+#include "mirage/utils-private.h"
 
 #include <glib/gi18n-lib.h>
 
@@ -39,7 +40,7 @@
 
 
 /**********************************************************************\
- *                          Private structure                         *
+ *                  Object and its private structure                  *
 \**********************************************************************/
 struct _MirageSessionPrivate
 {
@@ -62,7 +63,10 @@ struct _MirageSessionPrivate
 
     /* CD-Text list */
     GList *languages_list;
-} ;
+};
+
+
+G_DEFINE_TYPE_WITH_PRIVATE(MirageSession, mirage_session, MIRAGE_TYPE_OBJECT)
 
 
 /**********************************************************************\
@@ -73,7 +77,7 @@ static MirageTrack *mirage_session_find_track_with_subchannel (MirageSession *se
     MirageTrack *track = NULL;
 
     /* Go over all tracks, and find the first one with fragment that contains
-       subchannel... */
+     * subchannel... */
     gint num_tracks = mirage_session_get_number_of_tracks(self);
     for (gint i = 0; i < num_tracks; i++) {
         track = mirage_session_get_track_by_index(self, i, NULL);
@@ -104,8 +108,8 @@ static gchar *mirage_session_scan_for_mcn (MirageSession *self)
     }
 
     /* According to INF8090, MCN, if present, must be encoded in at least
-       one sector in 100 consequtive sectors. So we read first hundred
-       sectors' subchannel, and extract MCN if we find it. */
+     * one sector in 100 consequtive sectors. So we read first hundred
+     * sectors' subchannel, and extract MCN if we find it. */
     MirageFragment *fragment = mirage_track_find_fragment_with_subchannel(track, NULL);
     gint start_address = mirage_fragment_get_address(fragment);
     g_object_unref(fragment);
@@ -215,7 +219,7 @@ static void mirage_session_track_layout_changed_handler (MirageSession *self, Mi
 static void mirage_session_remove_track (MirageSession *self, MirageTrack *track)
 {
     /* Disconnect signal handler (find it by handler function and user data) */
-    g_signal_handlers_disconnect_by_func(track, mirage_session_track_layout_changed_handler, self);
+    mirage_signal_handlers_disconnect_by_func(track, G_CALLBACK(mirage_session_track_layout_changed_handler), self);
 
     /* Remove track from list and unref it */
     self->priv->tracks_list = g_list_remove(self->priv->tracks_list, track);
@@ -325,8 +329,8 @@ MirageSessionType mirage_session_get_session_type (MirageSession *self)
 void mirage_session_set_mcn (MirageSession *self, const gchar *mcn)
 {
     /* MCN can be set only if none of the tracks have fragments that contain
-       subchannel; this is because MCN is encoded in the subchannel, and cannot
-       be altered... */
+     * subchannel; this is because MCN is encoded in the subchannel, and cannot
+     * be altered... */
     if (self->priv->mcn_fixed) {
         MIRAGE_DEBUG(self, MIRAGE_DEBUG_SESSION, "%s: MCN is already encoded in subchannel!\n", __debug__);
     } else {
@@ -528,9 +532,9 @@ void mirage_session_set_leadout_length (MirageSession *self, gint length)
     leadout = mirage_session_get_track_by_number(self, MIRAGE_TRACK_LEADOUT, NULL);
 
     /* Now, check if leadout already has a fragment... if it has (and it should
-       have only one, unless I screwed up somewhere), then we'll simply readjust
-       its length. If not, we need to create it... The simplest way is to try to
-       get the last fragment in track */
+     * have only one, unless I screwed up somewhere), then we'll simply readjust
+     * its length. If not, we need to create it... The simplest way is to try to
+     * get the last fragment in track */
     fragment = mirage_track_get_fragment_by_index(leadout, -1, NULL);
     if (!fragment) {
         /* Create NULL fragment */
@@ -635,11 +639,11 @@ void mirage_session_add_track_by_index (MirageSession *self, gint index, MirageT
     mirage_object_set_parent(MIRAGE_OBJECT(track), self);
 
     /* Insert track into track list... take into account that lead-in has index 0,
-       thus all indexes should be increased by 1 */
+     * thus all indexes should be increased by 1 */
     self->priv->tracks_list = g_list_insert(self->priv->tracks_list, track, index + 1);
 
     /* Connect track modified signal */
-    g_signal_connect_swapped(track, "layout-changed", (GCallback)mirage_session_track_layout_changed_handler, self);
+    g_signal_connect_swapped(track, "layout-changed", G_CALLBACK(mirage_session_track_layout_changed_handler), self);
 
     /* Bottom-up change */
     mirage_session_commit_bottomup_change(self);
@@ -650,7 +654,7 @@ void mirage_session_add_track_by_index (MirageSession *self, gint index, MirageT
  * @self: a #MirageSession
  * @number: (in): track number for the added track
  * @track: (in) (transfer full): a #MirageTrack to be added
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Adds track to session layout.
  *
@@ -687,7 +691,7 @@ gboolean mirage_session_add_track_by_number (MirageSession *self, gint number, M
     self->priv->tracks_list = g_list_insert_sorted(self->priv->tracks_list, track, (GCompareFunc)sort_tracks_by_number);
 
     /* Connect track modified signal */
-    g_signal_connect_swapped(track, "layout-changed", (GCallback)mirage_session_track_layout_changed_handler, self);
+    g_signal_connect_swapped(track, "layout-changed", G_CALLBACK(mirage_session_track_layout_changed_handler), self);
 
     /* Bottom-up change */
     mirage_session_commit_bottomup_change(self);
@@ -699,7 +703,7 @@ gboolean mirage_session_add_track_by_number (MirageSession *self, gint number, M
  * mirage_session_remove_track_by_index:
  * @self: a #MirageSession
  * @index: (in): index of track to be removed
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Removes track from session layout.
  *
@@ -734,7 +738,7 @@ gboolean mirage_session_remove_track_by_index (MirageSession *self, gint index,
  * mirage_session_remove_track_by_number:
  * @self: a #MirageSession
  * @number: (in): track number of track to be removed
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Removes track from session layout.
  *
@@ -791,7 +795,7 @@ void mirage_session_remove_track_by_object (MirageSession *self, MirageTrack *tr
  * mirage_session_get_track_by_index:
  * @self: a #MirageSession
  * @index: (in): index of track to be retrieved
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Retrieves track by index. If @index is negative, tracks from the end of
  * layout are retrieved (e.g. -1 is for last track, -2 for second-to-last
@@ -817,8 +821,8 @@ MirageTrack *mirage_session_get_track_by_index (MirageSession *self, gint index,
     }
 
     /* Get index-th item from list... take into account the fact that index needs
-       to be increased by one, because first track we'll get with following function
-       will be the lead-in... */
+     * to be increased by one, because first track we'll get with following function
+     * will be the lead-in... */
     track = g_list_nth_data(self->priv->tracks_list, index + 1);
 
     if (!track) {
@@ -833,7 +837,7 @@ MirageTrack *mirage_session_get_track_by_index (MirageSession *self, gint index,
  * mirage_session_get_track_by_number:
  * @self: a #MirageSession
  * @number: (in): number of track to be retrieved
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Retrieves track by track number.
  *
@@ -870,7 +874,7 @@ MirageTrack *mirage_session_get_track_by_number (MirageSession *self, gint track
  * mirage_session_get_track_by_address:
  * @self: a #MirageSession
  * @address: (in): address belonging to track to be retrieved
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Retrieves track by address. @address must be valid (disc-relative) sector
  * address that is part of the track to be retrieved (i.e. lying between tracks's
@@ -913,8 +917,8 @@ MirageTrack *mirage_session_get_track_by_address (MirageSession *self, gint addr
 /**
  * mirage_session_enumerate_tracks:
  * @self: a #MirageSession
- * @func: (in) (scope call): callback function
- * @user_data: (in) (closure): data to be passed to callback function
+ * @func: (in) (scope call) (closure user_data): callback function
+ * @user_data: (in) (nullable): data to be passed to callback function
  *
  * Iterates over tracks list, calling @func for each track in the layout.
  *
@@ -938,7 +942,7 @@ gboolean mirage_session_enumerate_tracks (MirageSession *self, MirageEnumTrackCa
  * mirage_session_get_track_before:
  * @self: a #MirageSession
  * @track: (in): a track
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Retrieves track that comes before @track.
  *
@@ -953,7 +957,7 @@ MirageTrack *mirage_session_get_track_before (MirageSession *self, MirageTrack *
     /* Get index of given track in the list */
     index = g_list_index(self->priv->tracks_list, track);
     if (index == -1) {
-        g_set_error(error, MIRAGE_ERROR, MIRAGE_ERROR_SESSION_ERROR, Q_("Track %p is not in session layout!"), track);
+        g_set_error(error, MIRAGE_ERROR, MIRAGE_ERROR_SESSION_ERROR, Q_("Track %p is not in session layout!"), (void *)track);
         return NULL;
     }
     index -= 1; /* Because lead-in has index 0... */
@@ -963,7 +967,7 @@ MirageTrack *mirage_session_get_track_before (MirageSession *self, MirageTrack *
         return mirage_session_get_track_by_index(self, index - 1, error);
     }
 
-    g_set_error(error, MIRAGE_ERROR, MIRAGE_ERROR_DISC_ERROR, Q_("Track before track %p not found!"), track);
+    g_set_error(error, MIRAGE_ERROR, MIRAGE_ERROR_DISC_ERROR, Q_("Track before track %p not found!"), (void *)track);
     return NULL;
 }
 
@@ -971,7 +975,7 @@ MirageTrack *mirage_session_get_track_before (MirageSession *self, MirageTrack *
  * mirage_session_get_track_after:
  * @self: a #MirageSession
  * @track: (in): a track
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Retrieves track that comes after @track.
  *
@@ -987,7 +991,7 @@ MirageTrack *mirage_session_get_track_after (MirageSession *self, MirageTrack *t
     /* Get index of given track in the list */
     index = g_list_index(self->priv->tracks_list, track);
     if (index == -1) {
-        g_set_error(error, MIRAGE_ERROR, MIRAGE_ERROR_SESSION_ERROR, Q_("Track %p is not in session layout!"), track);
+        g_set_error(error, MIRAGE_ERROR, MIRAGE_ERROR_SESSION_ERROR, Q_("Track %p is not in session layout!"), (void *)track);
         return NULL;
     }
     index -= 1; /* Because lead-in has index 0... */
@@ -998,7 +1002,7 @@ MirageTrack *mirage_session_get_track_after (MirageSession *self, MirageTrack *t
         return mirage_session_get_track_by_index(self, index + 1, error);
     }
 
-    g_set_error(error, MIRAGE_ERROR, MIRAGE_ERROR_DISC_ERROR, Q_("Track after track %p not found!"), track);
+    g_set_error(error, MIRAGE_ERROR, MIRAGE_ERROR_DISC_ERROR, Q_("Track after track %p not found!"), (void *)track);
     return NULL;
 }
 
@@ -1022,7 +1026,7 @@ gint mirage_session_get_number_of_languages (MirageSession *self)
  * @self: a #MirageSession
  * @code: (in): language code for the added language
  * @language: (in) (transfer full): a #MirageLanguage to be added
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Adds language to session.
  *
@@ -1060,7 +1064,7 @@ gboolean mirage_session_add_language (MirageSession *self, gint code, MirageLang
  * mirage_session_remove_language_by_index:
  * @self: a #MirageSession
  * @index: (in): index of language to be removed
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Removes language from session.
  *
@@ -1090,7 +1094,7 @@ gboolean mirage_session_remove_language_by_index (MirageSession *self, gint inde
  * mirage_session_remove_language_by_code:
  * @self: a #MirageSession
  * @code: (in): language code of language to be removed
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Removes language from session.
  *
@@ -1131,7 +1135,7 @@ void mirage_session_remove_language_by_object (MirageSession *self, MirageLangua
  * mirage_session_get_language_by_index:
  * @self: a #MirageSession
  * @index: (in): index of language to be retrieved
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Retrieves language by index. If @index is negative, languages from the end of
  * session are retrieved (e.g. -1 is for last language, -2 for second-to-last
@@ -1171,7 +1175,7 @@ MirageLanguage *mirage_session_get_language_by_index (MirageSession *self, gint
  * mirage_session_get_language_by_code:
  * @self: a #MirageSession
  * @code: (in): language code of language to be retrieved
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Retrieves language by language code.
  *
@@ -1207,8 +1211,8 @@ MirageLanguage *mirage_session_get_language_by_code (MirageSession *self, gint c
 /**
  * mirage_session_enumerate_languages:
  * @self: a #MirageSession
- * @func: (in) (scope call): callback function
- * @user_data: (in) (closure): data to be passed to callback function
+ * @func: (in) (scope call) (closure user_data): callback function
+ * @user_data: (in) (nullable): data to be passed to callback function
  *
  * Iterates over languages list, calling @func for each language.
  *
@@ -1277,7 +1281,7 @@ static gboolean set_cdtext_data (gint code, gint type, gint track_number, guint8
  * @self: a #MirageSession
  * @data: (in) (array length=len): buffer containing encoded CD-TEXT data
  * @len: (in): length of data in buffer
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Sets CD-TEXT data for session. It internally creates and uses #MirageCdTextCoder
  * object as a decoder to decode data in @data. Decoded data is stored in #MirageLanguage
@@ -1316,7 +1320,7 @@ gboolean mirage_session_set_cdtext_data (MirageSession *self, guint8 *data, gint
  * @self: a #MirageSession
  * @data: (out callee-allocates) (transfer full) (array length=len): location to return buffer with encoded CD-TEXT data
  * @len: (out): location to return length of data in buffer
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Returns CD-TEXT data for session. It internally creates and uses #MirageCdTextCoder
  * object as an encoder to encode data from #MirageLanguage objects from both session and
@@ -1327,15 +1331,15 @@ gboolean mirage_session_set_cdtext_data (MirageSession *self, guint8 *data, gint
  */
 gboolean mirage_session_get_cdtext_data (MirageSession *self, guint8 **data, gint *len, GError **error)
 {
-    gint num_languages;
-    gint num_tracks;
+    guint num_languages;
+    guint num_tracks;
     gint buflen;
     guint8 *buffer;
     MirageCdTextCoder *encoder;
 
     /* Allocate space... technically, there could be 255 packs (each 18-byte long)
-       per every language... and spec says we support 8 of those. So we play safe
-       here; get number of languages and go for max number of packs */
+     * per every language... and spec says we support 8 of those. So we play safe
+     * here; get number of languages and go for max number of packs */
     num_languages = mirage_session_get_number_of_languages(self);
     num_tracks = mirage_session_get_number_of_tracks(self);
 
@@ -1368,7 +1372,7 @@ gboolean mirage_session_get_cdtext_data (MirageSession *self, guint8 **data, gin
     };
 
     /* Add all languages' data to encoder */
-    for (gint i = 0; i < num_languages; i++) {
+    for (guint i = 0; i < num_languages; i++) {
         MirageLanguage* session_language;
         gint code;
 
@@ -1383,7 +1387,7 @@ gboolean mirage_session_get_cdtext_data (MirageSession *self, guint8 **data, gin
         mirage_cdtext_encoder_set_block_info(encoder, i, code, 0, 0, NULL);
 
         /* Pack all supported pack types */
-        for (gint j = 0; j < G_N_ELEMENTS(pack_types); j++) {
+        for (guint j = 0; j < G_N_ELEMENTS(pack_types); j++) {
             gint pack_type = pack_types[j];
 
             const guint8 *session_language_data = NULL;
@@ -1395,7 +1399,7 @@ gboolean mirage_session_get_cdtext_data (MirageSession *self, guint8 **data, gin
             }
 
             /* Now get and pack the same data for the all tracks */
-            for (gint k = 0; k < num_tracks; k++) {
+            for (guint k = 0; k < num_tracks; k++) {
                 MirageTrack *track;
                 gint number;
 
@@ -1440,7 +1444,7 @@ gboolean mirage_session_get_cdtext_data (MirageSession *self, guint8 **data, gin
 /**
  * mirage_session_get_prev:
  * @self: a #MirageSession
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Retrieves session that is placed before @self in disc layout.
  *
@@ -1469,7 +1473,7 @@ MirageSession *mirage_session_get_prev (MirageSession *self, GError **error)
 /**
  * mirage_session_get_next:
  * @self: a #MirageSession
- * @error: (out) (allow-none): location to store error, or %NULL
+ * @error: (out) (optional): location to store error, or %NULL
  *
  * Retrieves session that is placed after @self in disc layout.
  *
@@ -1499,9 +1503,6 @@ MirageSession *mirage_session_get_next (MirageSession *self, GError **error)
 /**********************************************************************\
  *                             Object init                            *
 \**********************************************************************/
-G_DEFINE_TYPE_WITH_PRIVATE(MirageSession, mirage_session, MIRAGE_TYPE_OBJECT)
-
-
 static void mirage_session_init (MirageSession *self)
 {
     MirageTrack *track;
@@ -1540,7 +1541,7 @@ static void mirage_session_dispose (GObject *gobject)
         if (entry->data) {
             MirageTrack *track = entry->data;
             /* Disconnect signal handler and unref */
-            g_signal_handlers_disconnect_by_func(track, mirage_session_track_layout_changed_handler, self);
+            mirage_signal_handlers_disconnect_by_func(track, G_CALLBACK(mirage_session_track_layout_changed_handler), self);
             g_object_unref(track);
 
             entry->data = NULL;
@@ -1558,7 +1559,7 @@ static void mirage_session_dispose (GObject *gobject)
     }
 
     /* Chain up to the parent class */
-    return G_OBJECT_CLASS(mirage_session_parent_class)->dispose(gobject);
+    G_OBJECT_CLASS(mirage_session_parent_class)->dispose(gobject);
 }
 
 static void mirage_session_finalize (GObject *gobject)
@@ -1571,7 +1572,7 @@ static void mirage_session_finalize (GObject *gobject)
     g_list_free(self->priv->languages_list);
 
     /* Chain up to the parent class */
-    return G_OBJECT_CLASS(mirage_session_parent_class)->finalize(gobject);
+    G_OBJECT_CLASS(mirage_session_parent_class)->finalize(gobject);
 }
 
 static void mirage_session_class_init (MirageSessionClass *klass)
